@@ -8,7 +8,9 @@ from collections import Counter
 import string, nltk
 from nltk.corpus import stopwords
 import urllib.request, json
-
+nltk.download('wordnet')
+nltk.download('punkt')
+nltk.download('stopwords')
 
 
 def process_message(message):
